@@ -6,10 +6,13 @@ my $mw = MainWindow->new;
 
 my @items = qw(red blue yellow green orange purple brown black white);
 
+my $value;
+
 my $jcb = $mw->JComboBox(
   -mode => 'editable',
   -listbackground => 'white',
   -highlightthickness => 0,
+  -textvariable => \$value,
   -relief => 'sunken',  
   -maxrows => 5,
   -choices => [
@@ -18,4 +21,13 @@ my $jcb = $mw->JComboBox(
   ]
 )->pack( -padx => 20, -pady => 20);
 
+$mw->Button(
+  -text => 'print value',
+  -command => sub {
+    print $jcb->getSelectedValue . "\n";
+    print $value . "\n";
+})->pack;
+    
+
+
 MainLoop;
